Page Menu
Home
Phabricator
Search
Configure Global Search
Log In
Files
F14039745
D14528.id35246.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Award Token
Flag For Later
Size
949 B
Referenced Files
None
Subscribers
None
D14528.id35246.diff
View Options
diff --git a/src/applications/files/transform/PhabricatorFileImageTransform.php b/src/applications/files/transform/PhabricatorFileImageTransform.php
--- a/src/applications/files/transform/PhabricatorFileImageTransform.php
+++ b/src/applications/files/transform/PhabricatorFileImageTransform.php
@@ -119,9 +119,9 @@
$out = new TempFile();
$future = new ExecFuture('convert %s %Ls %s', $tmp, $argv, $out);
// Don't spend more than 10 seconds resizing; just fail if it takes longer
// than that.
- $future->setTimeout(10)->resolvex();
+ $future->setTimeout(60)->resolvex();
$data = Filesystem::readFile($out);
@@ -259,7 +259,7 @@
$file = $this->file;
- $max_size = (1024 * 1024 * 4);
+ $max_size = (1024 * 1024 * 16);
$img_size = $file->getByteSize();
if ($img_size > $max_size) {
throw new Exception(
@@ -119,9 +119,9 @@
$out = new TempFile();
$future = new ExecFuture('convert %s %Ls %s', $tmp, $argv, $out);
- // Don't spend more than 10 seconds resizing; just fail if it takes longer
+ // Don't spend more than 60 seconds resizing; just fail if it takes longer
// than that.
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Tue, Nov 12, 6:15 AM (1 w, 10 h ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
6712580
Default Alt Text
D14528.id35246.diff (949 B)
Attached To
Mode
D14528: Increase the maximum size eligible for image transforms configurable from 4MB->16MB
Attached
Detach File
Event Timeline
Log In to Comment